Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(439)

Unified Diff: ui/base/cursor/image_cursors.h

Issue 2949353003: Implement large cursors in Mushrome. (Closed)
Patch Set: rename everything to CursorSize Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/base/cursor/cursors_aura.cc ('k') | ui/base/cursor/image_cursors.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/base/cursor/image_cursors.h
diff --git a/ui/base/cursor/image_cursors.h b/ui/base/cursor/image_cursors.h
index 36e5465697cf32506aff20b979acf55975a1712a..43b40e01f4055e01c25263cf1662e61f254e9684 100644
--- a/ui/base/cursor/image_cursors.h
+++ b/ui/base/cursor/image_cursors.h
@@ -33,8 +33,8 @@ class UI_BASE_EXPORT ImageCursors {
// size of the image to load. Returns true if the cursor image is reloaded.
bool SetDisplay(const display::Display& display, float scale_factor);
- // Sets the type of the mouse cursor icon.
- void SetCursorSet(CursorSetType cursor_set);
+ // Sets the size of the mouse cursor icon.
+ void SetCursorSize(CursorSize cursor_size);
// Sets the platform cursor based on the native type of |cursor|.
void SetPlatformCursor(gfx::NativeCursor* cursor);
@@ -44,7 +44,7 @@ class UI_BASE_EXPORT ImageCursors {
void ReloadCursors();
std::unique_ptr<CursorLoader> cursor_loader_;
- CursorSetType cursor_set_;
+ CursorSize cursor_size_;
DISALLOW_COPY_AND_ASSIGN(ImageCursors);
};
« no previous file with comments | « ui/base/cursor/cursors_aura.cc ('k') | ui/base/cursor/image_cursors.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698